pub fn parse_peg_offset_value(params: Option<&Params>) -> Result<Option<f64>>
Extracts the peg offset value from order command parameters.
Returns an error if the value is present but not a valid f64.
f64